@@ -1,6 +1,5 @@
+from phml import PHML, filename_from_path
 from pathlib import Path
-from phml import PHMLCore
-from phml.utils import filename_from_path
 
 
 cdir = "components"
@@ -8,16 +7,16 @@ pdir = "pages"
 sdir = "site"
 
 if __name__ == "__main__":
-    core = PHMLCore()
+    phml = PHML()
 
     for cfile in Path(cdir).glob("**/*.phml"):
-        core.add(cfile)
+        phml.add(cfile, strip=cdir)
 
     Path(sdir).mkdir(parents=True, exist_ok=True)
 
     for pfile in Path(pdir).glob("**/*.phml"):
         (
-            core.load(pfile).write(
+            phml.load(pfile).write(
                 Path(sdir).joinpath(filename_from_path(pfile) + ".html").as_posix()
             )
         )
