@@ -1,6 +1,6 @@
 from phml.builder import p
-from phml.nodes import Text, Element, Position, Point
-from phml.utils import inspect
+from phml.core.nodes import AST, Text, Element, Position, Point
+from phml import inspect
 
 with_position = {
     "el": Element(
@@ -15,6 +15,10 @@ element<div> [1] <1:2-3:4 ~ 3>
 ''',
 }
 
+def test_with_ast():
+    assert inspect(AST(p())) == "root"
+    assert inspect(AST(p(p("div", p("div"))))) == "root [1]\n└0 element<div> [1]\n   └0 element<div/>"
+
 def test_with_position():
     assert inspect(with_position["el"]) == with_position["expected"]
 
@@ -57,7 +61,7 @@ def test_multiline_literal_node():
 with_props = {
     "el": p("div", {"id": "test", "hidden": True}),
     "expected": """\
-element<div>
+element<div/>
 │  properties: {
 │    "id": \"test\",
 │    "hidden": true
